@@ -948,7 +948,7 @@ class Subscribers(LPSubscribers):
         '''Add a subscriber to a bug.'''
         url = "%s/+addsubscriber" %self.__url
         args = { 'field.person': lplogin, 
-                 'UPDATE_SUBMIT': 'Add'
+                 'field.actions.add': 'Add'
                }
         result = self.__connection.post(url, args)
         if result.url == url:
@@ -1232,10 +1232,10 @@ class Bug(BugBase):
         
         self.__bugreport = BugReport(connection=self.__connection, xml=self.xmldoc, url=self.__url)
         self.__infotable = InfoTable(connection=self.__connection, xml=self.xmldoc.xpathEval('//body//table[@class="listing" or @class="duplicate listing"][1]'), url=self.__url)
-        self.__comments = Comments(connection=self.__connection, xml=self.xmldoc.xpathEval('//body//div[@class="boardComment"]'), url=self.__url)
+        self.__comments = Comments(connection=self.__connection, xml=self.xmldoc.xpathEval('//body//div[@class="boardComment "]'), url=self.__url)
         self.__attachments = Attachments(self.__comments, self.__connection, self.xmldoc.xpathEval('//body//div[@id="portlet-attachments"]/div/div/ul'))
         self.__duplicates = Duplicates(connection=self.__connection, xml=self.xmldoc, url=self.__url)
-        self.__secrecy = Secrecy(connection=self.__connection, xml=self.xmldoc.xpathEval('//body//div[@id="bug-properties"]'), url=self.__url)
+        self.__secrecy = Secrecy(connection=self.__connection, xml=self.xmldoc.xpathEval('//body//div[@id="big-badges"]'), url=self.__url)
         self.__subscribers = Subscribers(connection=self.__connection, xml=self.xmldoc.xpathEval('//body//div[@id="portlet-subscribers"]//div/ul'), url=self.__url)
         self.__mentor = Mentoring(connection=self.__connection, xml=self.xmldoc.xpathEval('//body//img [@src="/@@/mentoring"]/parent::p//a'), url=self.__url)
         self.__activity = ActivityLog(connection=self.__connection, url=self.__url)
