@@ -8,10 +8,14 @@ TODO:
 
 import launchpadbugs.connector as Connector
 
-BugList = Connector.ConnectBugList()
+BugList = Connector.ConnectBugList(method="text")
 
 print ">>> Getting a list of bugs"
 l = BugList("https://bugs.launchpad.net/ubuntu/+source/bughelper/+bugs")
+print
+print "str:", l
+print "repr:", repr(l)
+print
 for i in l.bugs:
     print i.bugnumber,
     print i.url,
